@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ type Session struct {
 }
 
 type PluginOptions struct {
-	System plugin.SystemOptions `conf:"optional"` //nolint:staticcheck
+	plugin.SystemOptions `conf:"optional,name=System"`
 	// Timeout is the amount of time to wait for a server to respond when
 	// first connecting and on follow up operations in the session.
 	Timeout int `conf:"optional,range=1:30"`
@@ -62,7 +62,7 @@ type PluginOptions struct {
 // Configure implements the Configurator interface.
 // Initializes configuration structures.
 func (p *Plugin) Configure(global *plugin.GlobalOptions, options interface{}) {
-	if err := conf.UnmarshalStrict(options, &p.options); err != nil {
+	if err := conf.Unmarshal(options, &p.options); err != nil {
 		p.Errf("cannot unmarshal configuration options: %s", err)
 	}
 
@@ -76,7 +76,7 @@ func (p *Plugin) Configure(global *plugin.GlobalOptions, options interface{}) {
 func (p *Plugin) Validate(options interface{}) error {
 	var opts PluginOptions
 
-	err := conf.UnmarshalStrict(options, &opts)
+	err := conf.Unmarshal(options, &opts)
 	if err != nil {
 		return err
 	}
